@@ -1,6 +1,6 @@
-#!/usr/bin/python3
+#!/usr/bin/python3 -u
 
-from joule.utils.time import now as time_now
+from joule.utilities import time_now
 from joule.client import ReaderModule
 import asyncio
 import numpy as np
@@ -78,9 +78,6 @@ ARGS_DESC = """
   #data rate in Hz
   rate = 500
 
-  [Inputs]
-  #none
-
   [Outputs]
   output = /path/to/output
 ---
@@ -97,11 +94,10 @@ class U3Reader(ReaderModule):
         grp.add_argument("--rate", type=float, required=True,
                          help="sample rate in Hz")
         #--channels
-        grp.add_argument("--channels")
+        grp.add_argument("--channels", required=True)
         parser.description = textwrap.dedent(ARGS_DESC)
 
     async def run(self, parsed_args, output):
-
         channels = [int(x) for x in parsed_args.channels.split(',')]
         rate = parsed_args.rate
         data_ts_inc = 1e6 / rate
